@@ -11,7 +11,7 @@
 
 package Config::Model::TkUI ;
 {
-  $Config::Model::TkUI::VERSION = '1.328';
+  $Config::Model::TkUI::VERSION = '1.330';
 }
 
 use strict;
@@ -823,7 +823,7 @@ sub disp_leaf {
 
     $tkt->itemCreate($path,2, -text => $cw->trim_value($value)) ;
 
-    $tkt->itemCreate($path,3, -text => $std_v) ;
+    $tkt->itemCreate($path,3, -text => $cw->trim_value($std_v)) ;
 }
 
 sub disp_node {
@@ -1261,7 +1261,7 @@ Dominique Dumont, (ddumont at cpan dot org)
     This file is part of Config-Model.
 
     Config-Model is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser Public License as
+    modify it under the terms of the GNU Lesser General Public License as
     published by the Free Software Foundation; either version 2.1 of
     the License, or (at your option) any later version.
 
@@ -1270,7 +1270,7 @@ Dominique Dumont, (ddumont at cpan dot org)
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     Lesser Public License for more details.
 
-    You should have received a copy of the GNU Lesser Public License
+    You should have received a copy of the GNU Lesser General Public License
     along with Config-Model; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
     02110-1301 USA
